@@ -3,14 +3,19 @@
 /**
  * mime.class
  *
- * Copyright (c) 2003-2004 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This file loads classes needed to handle mime messages.
  *
- * This contains functions needed to handle mime messages.
- *
- * $Id: mime.class.php,v 1.40.2.1 2004/02/24 15:57:12 kink Exp $
+ * @copyright &copy; 2003-2007 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: mime.class.php 12932 2008-02-10 16:49:47Z kink $
+ * @package squirrelmail
+ * @subpackage mime
  */
 
+/** @ignore */
+if (! defined('SM_PATH')) define('SM_PATH','../');
+
+/** Load in the entire MIME system */
 require_once(SM_PATH . 'class/mime/Rfc822Header.class.php');
 require_once(SM_PATH . 'class/mime/MessageHeader.class.php');
 require_once(SM_PATH . 'class/mime/AddressStructure.class.php');
@@ -20,4 +25,3 @@ require_once(SM_PATH . 'class/mime/Disposition.class.php');
 require_once(SM_PATH . 'class/mime/Language.class.php');
 require_once(SM_PATH . 'class/mime/ContentType.class.php');
 
-?>
