@@ -3,13 +3,12 @@
 /**
  * strings.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This code provides various string manipulation functions that are
- * used by the rest of the Squirrelmail code.
+ * used by the rest of the SquirrelMail code.
  *
- * @version $Id: strings.php,v 1.184.2.46 2006/02/23 21:17:44 kink Exp $
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: strings.php 13164 2008-05-23 17:31:51Z kink $
  * @package squirrelmail
  */
 
@@ -17,14 +16,14 @@
  * SquirrelMail version number -- DO NOT CHANGE
  */
 global $version;
-$version = '1.4.6';
+$version = '1.4.15';
 
 /**
  * SquirrelMail internal version number -- DO NOT CHANGE
  * $sm_internal_version = array (release, major, minor)
  */
 global $SQM_INTERNAL_VERSION;
-$SQM_INTERNAL_VERSION = array(1,4,6);
+$SQM_INTERNAL_VERSION = array(1,4,15);
 
 /**
  * There can be a circular issue with includes, where the $version string is
@@ -33,6 +32,10 @@ $SQM_INTERNAL_VERSION = array(1,4,6);
  */
 require_once(SM_PATH . 'functions/global.php');
 
+if (file_exists(SM_PATH . 'plugins/compatibility/functions.php')) {
+    include_once(SM_PATH . 'plugins/compatibility/functions.php');
+}
+
 /**
  * Wraps text at $wrap characters
  *
@@ -213,9 +216,14 @@ function readShortMailboxName($haystack, $needle) {
  * @return string the complete url for this page
  */
 function php_self () {
-    if ( sqgetGlobalVar('REQUEST_URI', $req_uri, SQ_SERVER) && !empty($req_uri) ) {
-      return $req_uri;
-    }
+    /*
+     * PHP 4.4.4 is giving the wrong REQUEST_URI. The Query string is missing.
+     * => I (stekkel) commented out the code because it's not realy needed. PHP_SELF in combinatiob
+     * with QUERY_STRING should do the job.
+     */
+//    if ( sqgetGlobalVar('REQUEST_URI', $req_uri, SQ_SERVER) && !empty($req_uri) ) {
+//      return $req_uri;
+//    }
 
     if ( sqgetGlobalVar('PHP_SELF', $php_self, SQ_SERVER) && !empty($php_self) ) {
 
@@ -245,7 +253,7 @@ function sqm_baseuri(){
     /**
      * If it is in the session, just return it.
      */
-    if (isset($base_uri)){
+    if (sqgetGlobalVar('base_uri',$base_uri,SQ_SESSION)){
         return $base_uri;
     }
     $dirs = array('|src/.*|', '|plugins/.*|', '|functions/.*|');
@@ -259,17 +267,15 @@ function sqm_baseuri(){
  *
  * Determines the location to forward to, relative to your server.
  * This is used in HTTP Location: redirects.
- * If this doesnt work correctly for you (although it should), you can
- * remove all this code except the last two lines, and have it return
- * the right URL for your site, something like:
- *
- *   http://www.example.com/squirrelmail/
+ * If set, it uses $config_location_base as the first part of the URL,
+ * specifically, the protocol, hostname and port parts. The path is
+ * always autodetected.
  *
  * @return string the base url for this SquirrelMail installation
  */
 function get_location () {
 
-    global $imap_server_type;
+    global $imap_server_type, $config_location_base;
 
     /* Get the path, handle virtual directories */
     if(strpos(php_self(), '?')) {
@@ -278,9 +284,18 @@ function get_location () {
         $path = php_self();
     }
     $path = substr($path, 0, strrpos($path, '/'));
-    if ( sqgetGlobalVar('sq_base_url', $full_url, SQ_SESSION) ) {
-      return $full_url . $path;
+
+    // proto+host+port are already set in config:
+    if ( !empty($config_location_base) ) {
+        // register it in the session just in case some plugin depends on this
+        sqsession_register($config_location_base . $path, 'sq_base_url');
+        return $config_location_base . $path ;
     }
+    // we computed it before, get it from the session:
+    if ( sqgetGlobalVar('sq_base_url', $full_url, SQ_SESSION) ) {
+        return $full_url . $path;
+    }
+    // else: autodetect
 
     /* Check if this is a HTTPS or regular HTTP request. */
     $proto = 'http://';
@@ -288,27 +303,34 @@ function get_location () {
     /*
      * If you have 'SSLOptions +StdEnvVars' in your apache config
      *     OR if you have HTTPS=on in your HTTP_SERVER_VARS
+     *     OR if you have HTTP_X_FORWARDED_PROTO=https in your HTTP_SERVER_VARS
      *     OR if you are on port 443
      */
     $getEnvVar = getenv('HTTPS');
-    if ((isset($getEnvVar) && !strcasecmp($getEnvVar, 'on')) ||
-        (sqgetGlobalVar('HTTPS', $https_on, SQ_SERVER) && !strcasecmp($https_on, 'on')) ||
+    if (!sqgetGlobalVar('HTTP_X_FORWARDED_PROTO', $forwarded_proto, SQ_SERVER))
+        $forwarded_proto = '';
+    if ((isset($getEnvVar) && strcasecmp($getEnvVar, 'on') === 0) ||
+        (sqgetGlobalVar('HTTPS', $https_on, SQ_SERVER) && strcasecmp($https_on, 'on') === 0) ||
+        (strcasecmp($forwarded_proto, 'https') === 0) ||
         (sqgetGlobalVar('SERVER_PORT', $server_port, SQ_SERVER) &&  $server_port == 443)) {
         $proto = 'https://';
     }
 
     /* Get the hostname from the Host header or server config. */
-    if ( !sqgetGlobalVar('HTTP_HOST', $host, SQ_SERVER) || empty($host) ) {
-      if ( !sqgetGlobalVar('SERVER_NAME', $host, SQ_SERVER) || empty($host) ) {
-        $host = '';
-      }
+    if ( !sqgetGlobalVar('HTTP_X_FORWARDED_HOST', $host, SQ_SERVER) || empty($host) ) {
+        if ( !sqgetGlobalVar('HTTP_HOST', $host, SQ_SERVER) || empty($host) ) {
+            if ( !sqgetGlobalVar('SERVER_NAME', $host, SQ_SERVER) || empty($host) ) {
+                $host = '';
+            }
+        }
     }
 
     $port = '';
-    if (! strstr($host, ':')) {
+    if (strpos($host, ':') === FALSE) {
         if (sqgetGlobalVar('SERVER_PORT', $server_port, SQ_SERVER)) {
             if (($server_port != 80 && $proto == 'http://') ||
-                ($server_port != 443 && $proto == 'https://')) {
+                ($server_port != 443 && $proto == 'https://' &&
+                 strcasecmp($forwarded_proto, 'https') !== 0)) {
                 $port = sprintf(':%d', $server_port);
             }
         }
@@ -565,7 +587,9 @@ function quoteimap($str) {
  * Trims array
  *
  * Trims every element in the array, ie. remove the first char of each element
+ * Obsolete: will probably removed soon
  * @param array array the array to trim
+ * @obsolete
  */
 function TrimArray(&$array) {
     foreach ($array as $k => $v) {
@@ -846,5 +870,14 @@ function sq_lowercase_array_vals(&$val,$key) {
     $val = strtolower($val);
 }
 
+/**
+ * Callback function to trim whitespace from a value, to be used in array_walk
+ * @param string $value value to trim
+ * @since 1.5.2 and 1.4.7
+ */
+function sq_trim_value ( &$value ) {
+    $value = trim($value);
+}
+
+
 $PHP_SELF = php_self();
-?>
